@@ -1,4 +1,5 @@
 """Utility functions for parsing inputs."""
+import copy
 import warnings
 
 import numpy as np
@@ -26,7 +27,17 @@ def _fig_dimensions(kwargs):
     return kwargs
 
 
-def _parse_deprecations(q, q_axis, val, horizontal, horiz_q_axis):
+def _parse_deprecations(
+    q,
+    q_axis,
+    val,
+    horizontal,
+    horiz_q_axis,
+    click_policy,
+    legend_click_policy,
+    conf_int_kwargs,
+    fill_kwargs,
+):
     if q_axis not in ("x", "y"):
         raise RuntimeError("Invalid `q_axis`. Must by 'x' or 'y'.")
 
@@ -49,11 +60,32 @@ def _parse_deprecations(q, q_axis, val, horizontal, horiz_q_axis):
                 "`val` and `q` in disagreement. Use `q`; `val` is deprecated."
             )
 
+        warnings.warn(f"`val` is deprecated. Use `q`. Using q={q}.", DeprecationWarning)
+
+    if click_policy is not None:
+        if legend_click_policy is None:
+            legend_click_policy = click_policy
+        elif click_policy != legend_click_policy:
+            raise RuntimeError(
+                "`click_policy` and `legend_click_policy` in disagreement. Use `legend_click_policy`; `click_policy` is deprecated."
+            )
+
         warnings.warn(
-            f"`val` is deprecated. Use `q`. Using `q={q}.", DeprecationWarning
+            f"`click_policy` is deprecated. Use `legend_click_policy`. Using legend_click_policy='{legend_click_policy}'."
         )
 
-    return q
+    if conf_int_kwargs is not None:
+        if fill_kwargs is None:
+            fill_kwargs = copy.copy(conf_int_kwargs)
+            warnings.warn(f"`conf_int_kwargs is deprecated. Use `fill_kwargs`.")
+        elif conf_int_kwargs != fill_kwargs:
+            raise RuntimeError(
+                "`fill_kwargs` and `conf_int_kwargs` in disagreement. Use `fill_kwargs`; `conf_int_kwargs` is deprecated."
+            )
+
+        warnings.warn(f"`conf_int_kwargs is deprecated. Use `fill_kwargs`.")
+
+    return q, legend_click_policy, fill_kwargs
 
 
 def _data_cats(data, q, cats, show_legend, legend_label):
@@ -107,9 +139,14 @@ def _fill_between(p, x1=None, y1=None, x2=None, y2=None, **kwargs):
         Plot populated with fill-between.
 
     """
-    patch = p.patch(
-        x=np.concatenate((x1, x2[::-1])), y=np.concatenate((y1, y2[::-1])), **kwargs
-    )
+    x = list(x1) + list(x2)[::-1]
+    y = list(y1) + list(y2)[::-1]
+    patch = p.patch(x=x, y=y, **kwargs)
+
+    # Old way; only works for Numpy arrays
+    # patch = p.patch(
+    #     x=np.concatenate((x1, x2[::-1])), y=np.concatenate((y1, y2[::-1])), **kwargs
+    # )
 
     return p, patch
 
@@ -206,8 +243,8 @@ def _check_cat_input(
     if q is None:
         raise RuntimeError("`q` argument must be provided.")
 
-    if type(palette) not in [list, tuple]:
-        raise RuntimeError("`palette` must be a list or tuple.")
+    if type(palette) not in [list, tuple, str]:
+        raise RuntimeError("`palette` must be a list, tuple or string.")
 
     if q not in df.columns:
         raise RuntimeError(f"{q} is not a column in the inputted data frame")
@@ -222,6 +259,10 @@ def _check_cat_input(
             if cat not in df.columns:
                 raise RuntimeError(f"{cat} is not a column in the inputted data frame")
     else:
+        if type(cats) == tuple:
+            raise RuntimeError(
+                "Cannot have tuples as data frame column names if there is only one categorical variable."
+            )
         if cats not in df.columns:
             raise RuntimeError(f"{cats} is not a column in the inputted data frame")
 
